## dbt-adapters 1.22.1 - December 17, 2025

### Fixes

- Fix volatility specificaiton for python aggregate functions ([#1504](https://github.com/dbt-labs/dbt-adapters/issues/1504))

### Under the Hood

- Breakdown schema synchronization macros to enable more detailed operations like nested structures schema modifications ([#599](https://github.com/dbt-labs/dbt-adapters/issues/599))

### Contributors
- [@Kayrnt](https://github.com/Kayrnt) ([#599](https://github.com/dbt-labs/dbt-adapters/issues/599))
